Struct cbor::value::Cursor
[−]
[src]
pub struct Cursor<'r> {
// some fields omitted
}A Cursor allows conventient navigation in a Value AST.
Values can be converted to native Rust types if possible and
collections can be traversed using at or get.